@@ -6,6 +6,8 @@
  */
 #include "weatherforecast.h"
 #include <QJsonArray>
+#include <QJsonObject>
+
 namespace KWeatherCore
 {
 class WeatherForecast::WeatherForecastPrivate : public QSharedData
@@ -22,23 +24,13 @@ WeatherForecast::WeatherForecast()
 {
 }
 
-WeatherForecast::WeatherForecast(const WeatherForecast &other)
-    : d(other.d)
-{
-}
+WeatherForecast::WeatherForecast(const WeatherForecast &) = default;
+WeatherForecast::WeatherForecast(WeatherForecast &&) noexcept = default;
 
-WeatherForecast &WeatherForecast::operator=(const WeatherForecast &other)
-{
-    if (this != &other) {
-        d = other.d;
-    }
+WeatherForecast &WeatherForecast::operator=(const WeatherForecast &) = default;
+WeatherForecast &WeatherForecast::operator=(WeatherForecast &&) noexcept = default;
 
-    return *this;
-}
-
-WeatherForecast::~WeatherForecast()
-{
-}
+WeatherForecast::~WeatherForecast() = default;
 
 QJsonObject WeatherForecast::toJson() const
 {
@@ -63,7 +55,7 @@ WeatherForecast WeatherForecast::fromJson(const QJsonObject &obj)
     for (const auto &d : array) {
         dayVec.push_back(DailyWeatherForecast::fromJson(d.toObject()));
     }
-    w.setDailyWeatherForecast(dayVec);
+    w.setDailyWeatherForecast(std::move(dayVec));
     w.setCoordinate(obj[QLatin1String("lat")].toDouble(), obj[QLatin1String("lon")].toDouble());
     w.setTimezone(obj[QLatin1String("timezone")].toString());
     w.setCreatedTime(QDateTime::fromString(obj[QLatin1String("createdTime")].toString(), Qt::ISODate));
@@ -98,10 +90,6 @@ void WeatherForecast::setTimezone(QString timezone)
 {
     d->timezone = std::move(timezone);
 }
-void WeatherForecast::setDailyWeatherForecast(const std::vector<DailyWeatherForecast> &forecast)
-{
-    d->dailyWeatherForecast = forecast;
-}
 void WeatherForecast::setDailyWeatherForecast(std::vector<DailyWeatherForecast> &&forecast)
 {
     d->dailyWeatherForecast = std::move(forecast);
@@ -117,7 +105,7 @@ WeatherForecast &WeatherForecast::operator+=(HourlyWeatherForecast &&forecast)
 
     // if not find, append it at end
     auto newDay = DailyWeatherForecast();
-    newDay += forecast;
+    newDay += std::move(forecast);
     d->dailyWeatherForecast.push_back(std::move(newDay));
     return *this;
 }
